# sky130ph v0.0.5

Skywater photonics PDK for the SKY130 process node. The documentation is at https://byucamacholab.github.io/sky130ph/

## Installation

`pip install sky130ph`

## TODO

- Add component library
- Add tests
- Test components

## Authors

- Skandan Chandrasekar
- Sequoia Ploeg
- Elise Bangerter
- Joel Kartchner
